==> zio-aws-workspaces_2.13-5.17.170.1-sources.jar: zio/aws/workspaces/model/StartRequest.scala <==
package zio.aws.workspaces.model
import zio.aws.workspaces.model.primitives.WorkspaceId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class StartRequest(
    workspaceId: Optional[WorkspaceId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workspaces.model.StartRequest = {
    import StartRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workspaces.model.StartRequest
      .builder()
      .optionallyWith(
        workspaceId.map(value => WorkspaceId.unwrap(value): java.lang.String)
      )(_.workspaceId)
      .build()
  }
  def asReadOnly: zio.aws.workspaces.model.StartRequest.ReadOnly =
    zio.aws.workspaces.model.StartRequest.wrap(buildAwsValue())
}
object StartRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workspaces.model.StartRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workspaces.model.StartRequest =
      zio.aws.workspaces.model.StartRequest(workspaceId.map(value => value))
    def workspaceId: Optional[WorkspaceId]
    def getWorkspaceId: ZIO[Any, AwsError, WorkspaceId] =
      AwsError.unwrapOptionField("workspaceId", workspaceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workspaces.model.StartRequest
  ) extends zio.aws.workspaces.model.StartRequest.ReadOnly {
    override val workspaceId: Optional[WorkspaceId] = zio.aws.core.internal
      .optionalFromNullable(impl.workspaceId())
      .map(value => zio.aws.workspaces.model.primitives.WorkspaceId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.workspaces.model.StartRequest
  ): zio.aws.workspaces.model.StartRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-workspaces_3-5.17.147.1-sources.jar: zio/aws/workspaces/model/StartRequest.scala <==
package zio.aws.workspaces.model
import zio.aws.workspaces.model.primitives.WorkspaceId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class StartRequest(workspaceId: Option[WorkspaceId] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workspaces.model.StartRequest = {
    import StartRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workspaces.model.StartRequest
      .builder()
      .optionallyWith(
        workspaceId.map(value => WorkspaceId.unwrap(value): java.lang.String)
      )(_.workspaceId)
      .build()
  }
  def asReadOnly: zio.aws.workspaces.model.StartRequest.ReadOnly =
    zio.aws.workspaces.model.StartRequest.wrap(buildAwsValue())
}
object StartRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workspaces.model.StartRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workspaces.model.StartRequest =
      zio.aws.workspaces.model.StartRequest(workspaceId.map(value => value))
    def workspaceId: Option[WorkspaceId]
    def getWorkspaceId: ZIO[Any, AwsError, WorkspaceId] =
      AwsError.unwrapOptionField("workspaceId", workspaceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workspaces.model.StartRequest
  ) extends zio.aws.workspaces.model.StartRequest.ReadOnly {
    override val workspaceId: Option[WorkspaceId] = scala
      .Option(impl.workspaceId())
      .map(value => zio.aws.workspaces.model.primitives.WorkspaceId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.workspaces.model.StartRequest
  ): zio.aws.workspaces.model.StartRequest.ReadOnly = new Wrapper(impl)
}
